package com.zhilian.business.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zhilian.business.domain.Vehicle;
import com.zhilian.business.mapper.VehicleMapper;
import com.zhilian.business.service.VehicleService;
import com.zhilian.common.core.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class VehicleServiceImpl extends ServiceImpl<VehicleMapper, Vehicle> implements VehicleService {
    @Autowired
    private VehicleMapper vehicleMapper;

    @Override
    public List<Vehicle> selectVehicleList(Vehicle vehicle) {
        LambdaQueryWrapper<Vehicle> queryWrapper = new LambdaQueryWrapper<>();
        //模糊条件 查询VIN
        if (StringUtils.isNotEmpty(vehicle.getVehicleVIN())) {
            queryWrapper.like(Vehicle::getVehicleVIN, vehicle.getVehicleVIN());
        }
        // 精确查询 - 查询类型
        if (vehicle.getVehicleTypeId() != null) {
            queryWrapper.eq(Vehicle::getVehicleTypeId, vehicle.getVehicleTypeId());
        }
        //模糊查询 车辆电机厂商
        if (StringUtils.isNotEmpty(vehicle.getMotorId())) {
            queryWrapper.like(Vehicle::getMotorId, vehicle.getMotorId());
        }
        //模糊查询 车辆电池厂商
        if (StringUtils.isNotEmpty(vehicle.getBatteryId())) {
            queryWrapper.like(Vehicle::getBatteryId, vehicle.getBatteryId());
        }
        //模糊查询 车辆电机ID
        if (StringUtils.isNotEmpty(vehicle.getVehicleMotor())) {
            queryWrapper.like(Vehicle::getVehicleMotor, vehicle.getVehicleMotor());
        }
        //模糊查询 车辆电池ID
        if (StringUtils.isNotEmpty(vehicle.getVehicleBattery())) {
            queryWrapper.like(Vehicle::getVehicleBattery, vehicle.getVehicleBattery());
        }
        //精确查询 车辆状态
        if (vehicle.getVehicleState() != null) {
            queryWrapper.eq(Vehicle::getVehicleState, vehicle.getVehicleState());
        }

//        queryWrapper.like(StringUtils.isNotEmpty(vehicle.getVehicleVIN()), Vehicle::getVehicleVIN, vehicle.getVehicleVIN())
//                .eq(vehicle.getVehicleTypeId() != null, Vehicle::getVehicleTypeId, vehicle.getVehicleTypeId())
//                .like(StringUtils.isNotEmpty(vehicle.getMotorID()), Vehicle::getMotorID, vehicle.getMotorID())
//                .like(StringUtils.isNotEmpty(vehicle.getBatteryID()), Vehicle::getBatteryID, vehicle.getBatteryID())
//                .like(StringUtils.isNotEmpty(vehicle.getMotorBusiness()), Vehicle::getMotorBusiness, vehicle.getMotorBusiness())
//                .like(StringUtils.isNotEmpty(vehicle.getBatteryBusiness()), Vehicle::getBatteryBusiness, vehicle.getBatteryBusiness())
//                .eq(vehicle.getVehicleState() != null, Vehicle::getVehicleState, vehicle.getVehicleState());
        return this.list(queryWrapper);
    }

    @Override
    public Vehicle getVehicleByVIN(String vehicleVIN) {
        LambdaQueryWrapper<Vehicle> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(Vehicle::getVehicleVIN, vehicleVIN);
        return vehicleMapper.selectOne(queryWrapper);
    }

    @Override
    public boolean updateState(Vehicle vehicle) {
        int update = vehicleMapper.update(vehicle, new LambdaQueryWrapper<Vehicle>().eq(Vehicle::getVehicleVIN, vehicle.getVehicleVIN()));
        if(update==0){
            return false;
        }
        return true;
    }

}
